==> haskell-crypto-pubkey-types-0.4.3-94-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-7InBW0u3qAYKF5fb8lmHdW
key: crypto-pubkey-types-0.4.3-7InBW0u3qAYKF5fb8lmHdW
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: 63ab58cc2474c65991a2a3ecb8751b07
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-7InBW0u3qAYKF5fb8lmHdW
depends:
    asn1-encoding-0.9.5-6xTC56rlj2161Wc0QnpN3c
    asn1-types-0.3.2-C4CHpadXLTCBj8vIRwXTVq base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-95-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-LddWx8eO0XT7MMqreSWTEL
key: crypto-pubkey-types-0.4.3-LddWx8eO0XT7MMqreSWTEL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: e74f7ba3009a96ef4c6db027153c3d43
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-LddWx8eO0XT7MMqreSWTEL
depends:
    asn1-encoding-0.9.5-FtBwZmITEqjG5wmLP5aEcM
    asn1-types-0.3.2-4cCwnYpGwdvAcPUkJr4Peh base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
